<?php

namespace NoccyLabs\Plugin\Manager;


class PluginManifest
{
    /** @var string Plugin name using dot notation */
    private $name;
    /** @var string Plugin version using semantic versioning (semver) */
    private $version;

    private $manifest;
    /** @var string The path to the plugin directory or archive */
    private $path;

    public static function create(string $name, string $version, array $manifest, $path = null) : PluginManifest
    {
        $pm = new PluginManifest();
        $pm->name = $name;
        $pm->version = $version;
        $pm->manifest = $manifest;
        $pm->path = $path;
        return $pm;
    }

    public static function createFromFile(string $file) : PluginManifest
    {

    }

    public function getName() : string
    {
        return $this->name;
    }

    public function getVersion() : string
    {
        return $this->version;
    }

    public function compareVersion(string $compare)
    {
        return version_compare($compare, $this->version);
    }

    public function translatePath(string $path) : string
    {
        if (is_dir($this->path)) {
            return $this->path . "/" . ltrim($path, "/");
        } elseif (fnmatch("*.zip", $this->path)) {
            return sprintf("zip://%s#%s", $this->path, ltrim($path, "/"));
        }
        throw new PluginManifestException("Manifest does not have a root directory");
    }

    public function getKey(string $name, $default = null)
    {
        return array_key_exists($name, $this->manifest) ? $this->manifest[$name] : $default;
    }

    public function __toString()
    {
        return sprintf("%s@%s", $this->name, $this->version);
    }
}